@@ -24,8 +24,10 @@ v_create_count                  int := 0;
 v_current_partition_id          bigint;
 v_current_partition_timestamp   timestamptz;
 v_default_tablename             text;
+v_default_version               text;
 v_drop_count                    int := 0;
 v_exact_control_type            text;
+v_installed_version             text;
 v_is_default                    text;
 v_job_id                        bigint;
 v_jobmon_schema                 text;
@@ -33,6 +35,7 @@ v_last_partition                text;
 v_last_partition_created        boolean;
 v_last_partition_id             bigint;
 v_last_partition_timestamp      timestamptz;
+v_library_version               text;
 v_max_id                        bigint;
 v_max_id_default                bigint;
 v_max_time_default              timestamptz;
@@ -95,6 +98,21 @@ IF p_jobmon THEN
 END IF;
 EXECUTE format('SELECT set_config(%L, %L, %L)', 'search_path', v_new_search_path, 'false');
 
+IF current_setting('server_version_num')::int >= 180000 THEN
+    SELECT extversion INTO v_installed_version FROM pg_catalog.pg_extension WHERE extname = 'pg_partman';
+    SELECT version INTO v_library_version FROM pg_catalog.pg_get_loaded_modules() WHERE module_name = 'pg_partman';
+
+    IF replace(v_installed_version, '.', '')::int < replace(v_library_version, '.', '')::int THEN
+        RAISE EXCEPTION 'The installed version of pg_partman (%) is less than the shared library version file that has been loaded (%). Please ensure the expected version of pg_partman is installed to the system, update the extension if needed and restart the PostgreSQL instance.', v_installed_version, v_library_version;
+    END IF;
+END IF;
+
+-- Try and catch the same situation of a new library file existing on disk but the extension version not being updated properly in the database. Not as reliable as new feature in PG18, but better than nothing. Only do a warning since this is less definitely a problem than a known library mismatch.
+SELECT default_version, installed_version INTO v_default_version, v_installed_version FROM pg_available_extensions WHERE name = 'pg_partman' AND default_version != installed_version;
+IF v_installed_version IS NOT NULL THEN
+    RAISE WARNING 'pg_partman version % is installed in the database but version % is the default available. Please ensure the expected version of pg_partman is installed to the system, update the extension in all relevant databases and restart the PostgreSQL instance if a new shared library module is available. See release notes for further details.', v_installed_version, v_default_version;
+END IF;
+
 IF v_jobmon_schema IS NOT NULL THEN
     v_job_id := add_job('PARTMAN RUN MAINTENANCE');
     v_step_id := add_step(v_job_id, 'Running maintenance loop');
@@ -234,7 +252,6 @@ LOOP
         FOR v_row_max_time IN
             SELECT partition_schemaname, partition_tablename FROM @extschema@.show_partitions(v_row.parent_table, 'DESC', false)
         LOOP
-
             IF v_control_type = 'time' OR (v_control_type = 'id' AND v_row.epoch <> 'none') THEN
                 EXECUTE format('SELECT %s::text FROM %I.%I LIMIT 1'
                                     , v_partition_expression
@@ -267,7 +284,6 @@ LOOP
             v_current_partition_timestamp = CURRENT_TIMESTAMP;
         END IF;
 
-
         -- If not ignoring the default table, check for max values there. If they are there and greater than all child values, use that instead
         -- Note the default is NOT to care about data in the default, so maintenance will fail if new child table boundaries overlap with
         --  data that exists in the default. This is intentional so user removes data from default to avoid larger problems.
@@ -337,6 +353,7 @@ LOOP
 
             v_last_partition_created := @extschema@.create_partition_time(v_row.parent_table
                                                         , ARRAY[v_next_partition_timestamp]);
+
             IF v_last_partition_created THEN
                 v_analyze := true;
                 v_create_count := v_create_count + 1;
