@@ -56,7 +56,7 @@ CREATE TABLE partman_test.declarative_objects(
   t TEXT,
   created_at TIMESTAMP NOT NULL
 ) PARTITION BY RANGE (created_at);
-SELECT create_parent('partman_test.declarative_objects', 'created_at', '1 week', p_premake := 2, p_start_partition := (NOW() - '4 weeks'::INTERVAL)::TEXT);
+SELECT create_partition('partman_test.declarative_objects', 'created_at', '1 week', p_premake := 2, p_start_partition := (NOW() - '4 weeks'::INTERVAL)::TEXT);
 -- Update config options you can't set at initial creation.
 UPDATE part_config
 SET retention='5 weeks', retention_keep_table = 'f', infinite_time_partitions = 't', constraint_valid = 'f', inherit_privileges = 't'
@@ -70,7 +70,7 @@ SELECT dump_partitioned_table_definition('partman_test.declarative_objects', p_i
 -- -- Note that spaces before each line are literal tabs (\t), not spaces
 SELECT is(
   (SELECT dump_partitioned_table_definition('partman_test.declarative_objects')),
-E'SELECT partman.create_parent(
+E'SELECT partman.create_partition(
 	p_parent_table := ''partman_test.declarative_objects'',
 	p_control := ''created_at'',
 	p_interval := ''7 days'',
